pub struct CheckPlan {Show 19 fields
pub schema_version: String,
pub plan_id: CheckPlanId,
pub case_id: VerificationCaseId,
pub method: CheckMethod,
pub planner_family: String,
pub check_names: Vec<String>,
pub promotion_class: PromotionClass,
pub reversibility_class: ReversibilityClass,
pub cheapest_adequate: bool,
pub promotable_if_completed: bool,
pub advisory_only: bool,
pub degraded: bool,
pub target_exactness: ExactnessLevelV1,
pub evidence_admissibility: EvidenceAdmissibilityV1,
pub proof_obligations_remaining: Vec<String>,
pub cheap_check_ladder: Vec<CheapCheckStatusV1>,
pub proof_profile: Option<ProofProfileV1>,
pub rationale: String,
pub input: Value,
}Expand description
A check plan specifying the verification method, promotion class, and proof profile for a case.
Fields
schema_version: Stringplan_id: CheckPlanIdcase_id: VerificationCaseIdmethod: CheckMethodplanner_family: Stringcheck_names: Vec<String>promotion_class: PromotionClassreversibility_class: ReversibilityClasscheapest_adequate: boolpromotable_if_completed: booladvisory_only: booldegraded: booltarget_exactness: ExactnessLevelV1evidence_admissibility: EvidenceAdmissibilityV1proof_obligations_remaining: Vec<String>cheap_check_ladder: Vec<CheapCheckStatusV1>proof_profile: Option<ProofProfileV1>rationale: Stringinput: ValueImplementations
Sourceimpl CheckPlan
impl CheckPlan
Sourcepub fn new(
case_id: VerificationCaseId,
method: CheckMethod,
check_names: Vec<String>,
promotion_class: PromotionClass,
reversibility_class: ReversibilityClass,
promotable_if_completed: bool,
advisory_only: bool,
degraded: bool,
rationale: impl Into<String>,
input: Value,
) -> CheckPlan
pub fn new( case_id: VerificationCaseId, method: CheckMethod, check_names: Vec<String>, promotion_class: PromotionClass, reversibility_class: ReversibilityClass, promotable_if_completed: bool, advisory_only: bool, degraded: bool, rationale: impl Into<String>, input: Value, ) -> CheckPlan
Creates a check plan with the default planner family and baseline admissibility policy.